Skip to contents

Returns regional FCAS market prices across the eight contingency services plus the two regulation services. Ten services are live in the NEM since R1/L1 Very Fast commenced on 9 October 2023.

Usage

aemo_fcas(region, start, end, service = NULL, intervention = FALSE)

Arguments

region

NEM region code.

start, end

Window (inclusive).

service

Optional character vector of service names (e.g. "RAISE6SEC", "LOWER60SEC", "RAISE1SEC").

intervention

Logical. See aemo_price().

Value

An aemo_tbl with one row per interval and columns for each requested FCAS RRP (AUD/MW).

Details

Thin wrapper over aemo_price(..., market = "fcas").

See also

Other price: aemo_price()

Examples

# \donttest{
op <- options(aemo.cache_dir = tempdir())
try({
  now <- Sys.time()
  f <- aemo_fcas("NSW1", now - 3600, now)
  head(f)
})
#> Warning: Cache integrity check failed for 3d68ee95afa8150e.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for 7e04a6690826e6ac.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for cfe993541435e59f.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for 4b5cbf73e6f00631.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for 829b75b548ad2f5f.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for f57d2ebe63c497d8.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for 987a3c03aabfd59f.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for 9efbd4132ed70868.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for 7972a9506feaf872.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for 6573637dad592f8a.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for 0c39ccd2bb4fdc51.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for cca2b959d5993570.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for f97cba749cf2e79b.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> Warning: Cache integrity check failed for 4322e37732a56d17.zip; re-downloading.
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#>  Downloading <http://nemweb.com.au/Reports/Current/DispatchIS_Reports/PUBLIC_D
#> 
#> # aemo_tbl: AEMO 5min fcas price NSW1
#> # Source:   http://nemweb.com.au
#> # Licence:  AEMO Copyright Permissions Notice
#> # Retrieved: 2026-04-28 19:14 UTC 
#> # Rows: 6  Cols: 14
#> 
#>        settlementdate regionid runno intervention raise6secrrp raise60secrrp
#> 1 2026-04-29 04:15:00     NSW1     1            0         0.09          0.15
#> 2 2026-04-29 04:20:00     NSW1     1            0         0.09          0.15
#> 3 2026-04-29 04:25:00     NSW1     1            0         0.10          0.15
#> 4 2026-04-29 04:30:00     NSW1     1            0         0.09          0.10
#> 5 2026-04-29 04:35:00     NSW1     1            0         0.09          0.10
#> 6 2026-04-29 04:40:00     NSW1     1            0         0.09          0.10
#>   raise5minrrp raiseregrrp lower6secrrp lower60secrrp lower5minrrp lowerregrrp
#> 1         0.03        5.50            0             0            0        1.20
#> 2         0.03        5.50            0             0            0        1.62
#> 3         0.03        6.03            0             0            0        1.20
#> 4         0.03        6.03            0             0            0        1.20
#> 5         0.03        3.47            0             0            0        1.00
#> 6         0.02        3.47            0             0            0        0.72
#>   raise1secrrp lower1secrrp
#> 1         0.03            0
#> 2         0.03            0
#> 3         0.03            0
#> 4         0.03            0
#> 5         0.03            0
#> 6         0.03            0
options(op)
# }