aemo_fcas: Frequency control ancillary services (FCAS) prices

View source: R/price.R

aemo_fcasR Documentation

Frequency control ancillary services (FCAS) prices

Description

Returns regional FCAS market prices across the eight contingency services plus the two regulation services. Ten services are live in the NEM since R1/L1 Very Fast commenced on 9 October 2023.

Usage

aemo_fcas(region, start, end, service = NULL, intervention = FALSE)

Arguments

region

NEM region code.

start, end

Window (inclusive).

service

Optional character vector of service names (e.g. "RAISE6SEC", "LOWER60SEC", "RAISE1SEC").

intervention

Logical. See aemo_price().

Details

Thin wrapper over aemo_price(..., market = "fcas").

Value

An aemo_tbl with one row per interval and columns for each requested FCAS RRP (AUD/MW).

See Also

Other price: aemo_price()

Examples


op <- options(aemo.cache_dir = tempdir())
try({
  now <- Sys.time()
  f <- aemo_fcas("NSW1", now - 3600, now)
  head(f)
})
options(op)


aemo documentation built on April 29, 2026, 1:07 a.m.